#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-1jYEViOFWRB13J5HOYUhcW
key:                  markdown-unlit-0.6.0-1jYEViOFWRB13J5HOYUhcW
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  eced36326502244665ede1ee13e1e5a4
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-1jYEViOFWRB13J5HOYUhcW
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

